@@ -1,4 +1,4 @@
-from mhd_model.model import MHD_MODEL_V0_1_LEGACY_PROFILE_NAME
+from mhd_model.model.definitions import MHD_MODEL_V0_1_LEGACY_PROFILE_NAME
 from mhd_model.model.v0_1.dataset.validation.profile.base import (
     EmbeddedRefValidation,
     RelationshipValidation,
@@ -948,11 +948,6 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
                 required=True,
                 target_ref_types=["data-provider"],
             ),
-            NodePropertyValidation(
-                node_type="study",
-                node_property_name="mhd_identifier",
-                contraints=PropertyConstraint(required=True, min_length=8),
-            ),
             NodePropertyValidation(
                 node_type="study",
                 node_property_name="repository_identifier",
