@@ -4,7 +4,9 @@ from typing_extensions import Annotated
 from mhd_model.model.v0_1.dataset.profiles.base.base import (
     MhdObjectType,
 )
-from mhd_model.model.v0_1.dataset.profiles.base.profile import MhDatasetBaseProfile
+from mhd_model.model.v0_1.dataset.profiles.base.profile import (
+    MhDatasetBaseProfile,
+)
 
 
 class MhDatasetMsProfile(MhDatasetBaseProfile):
