@@ -5,7 +5,7 @@ from typing import Any, Generator, OrderedDict
 import jsonschema
 from jsonschema import ValidationError, protocols, validators
 
-from mhd_model.model import (
+from mhd_model.model.definitions import (
     MHD_MODEL_V0_1_LEGACY_PROFILE_NAME,
     MHD_MODEL_V0_1_MS_PROFILE_NAME,
     SUPPORTED_SCHEMA_MAP,
@@ -632,7 +632,20 @@ class MhdModelValidator:
                                 instance={},
                             )
                         )
-
+                if item.contraints.pattern and val is not None:
+                    if not re.match(item.contraints.pattern, val):
+                        sub_path = [path, node_idx] if path else [node_idx]
+                        errors.append(
+                            jsonschema.ValidationError(
+                                message=f"{node_data.id_}: '{node_data.type_}' node at index "
+                                f"{node_idx} has a property named '{item.node_property_name}' "
+                                f"that violates pattern rule. Actual: {val}, Expected pattern: {item.contraints.pattern}",
+                                validator="check-property-constraint",
+                                context=(),
+                                path=sub_path,
+                                instance={},
+                            )
+                        )
                 if not min_length_violation and item.contraints.required:
                     if not val:
                         sub_path = [path, node_idx] if path else [node_idx]
@@ -1440,11 +1453,24 @@ class MhdModelValidator:
         items = []
         errors = []
         for idx, x in relationships.values():
-            if (
-                item.source == nodes[x.source_ref].type_
-                and item.target == nodes[x.target_ref].type_
-            ):
+            target_node = nodes.get(x.target_ref)
+
+            source_node = nodes.get(x.source_ref)
+            if item.source == source_node.type_ and item.target == target_node.type_:
                 items.append(x)
+            elif target_node.type_.startswith("x-") or source_node.type_.startswith(
+                "x-"
+            ):
+                expected_source = (
+                    item.source == source_node.type_
+                    or item.source.endswith(f"-{item.source}")
+                )
+                expected_target = (
+                    item.target == target_node.type_
+                    or item.target.endswith(f"-{item.target}")
+                )
+                if expected_source and expected_target:
+                    items.append(x)
         if len(items) < item.min:
             errors.append(
                 jsonschema.ValidationError(
